<?php

/**
 * Helper functions
 */

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function audiocast_pro_pingback_header() {
    if (is_singular() && pings_open()) {
        echo '<link rel="pingback" href="', bloginfo('pingback_url'), '">';
    }
}
add_action('wp_head', 'audiocast_pro_pingback_header');

/**
 * Adds classes to the body tag
 */
function audiocast_pro_body_classes($classes) {

    // Vars
    $post_layout  = audiocast_pro_post_layout();
    $container    = get_theme_mod('container_style', 'full-width');
    $post_style   = get_theme_mod('post_style', 'grid');

    // RTL
    if (is_rtl()) {
        $classes[] = 'rtl';
    }

    // Main class
    $classes[] = 'audiocast-theme';

    // Container style
    $classes[] = $container . '-container';

    // Sidebar enabled
    if (
        'left-sidebar' == $post_layout
        || 'right-sidebar' == $post_layout
        && 'full-width' != $container
    ) {
        $classes[] = 'has-sidebar';
    }

    // Content layout
    if ($post_layout) {
        $classes[] = $post_layout;
    }

    // Has featured image.
    if (is_singular() && has_post_thumbnail()) {
        $classes[] = 'has-featured-image';
    }

    // Content style
    if (
        is_home()
        || is_category()
        || is_tag()
        || is_date()
        || is_author()
    ) {
        $classes[] = 'post-style-' . $post_style;
    }

    // Return classes
    return apply_filters('audiocast_pro_body_classes', $classes);
}
add_filter('body_class', 'audiocast_pro_body_classes');

/**
 * Returns correct post layout.
 */
function audiocast_pro_post_layout() {

    // Define variables
    $class = 'right-sidebar';
    $meta  = get_post_meta(get_the_ID(), '_post_layout', true);

    // Check meta first to override and return (prevents filters from overriding meta)
    if (is_singular() && $meta && $meta !== 'default') {
        return $meta;
    }

    // Singular Page
    if (is_page()) {

        // Attachment
        if (is_attachment() && wp_attachment_is_image()) {
            $class = 'full-width';
        }

        // Gutenberg page template
        elseif (
            is_page_template('page-templates/gutenberg.php') ||
            is_page_template('page-templates/home-podcast.php')
        ) {
            $class = 'full-width';
        }

        // All other pages
        else {
            $class = get_theme_mod('page_layout', 'right-sidebar');
        }
    }

    // Home
    elseif (is_home()) {
        $class = get_theme_mod('blog_layout', 'right-sidebar');
    }

    // Archives
    elseif (
        is_category()
        || is_tag()
        || is_date()
        || is_author()
    ) {
        $class = get_theme_mod('archive_layout', 'right-sidebar');
    }

    // Singular Post
    elseif (is_singular('post')) {
        $class = get_theme_mod('post_layout', 'right-sidebar');
    }

    // 404 page
    elseif (is_404()) {
        $class = 'full-width-narrow';
    }

    // Podcast archives
    elseif (is_post_type_archive('podcast')) {
        $class = 'full-width';
    }

    // Single podcast
    elseif (is_singular('podcast')) {
        $class = 'full-width';
    }

    // All else
    else {
        $class = 'right-sidebar';
    }

    // Class should never be empty
    if (empty($class)) {
        $class = 'right-sidebar';
    }

    // Apply filters and return
    return apply_filters('audiocast_pro_post_layout_class', $class);
}

/**
 * Returns the correct sidebar region.
 */
function audiocast_pro_get_sidebar($sidebar = 'primary') {

    // Return the correct sidebar name & add useful hook
    $sidebar = apply_filters('audiocast_pro_get_sidebar', $sidebar);

    // Never show empty sidebar
    if (!is_active_sidebar($sidebar)) {
        $sidebar = 'primary';
    }

    return $sidebar;
}

/**
 * Adds custom classes to the array of post classes.
 */
function audiocast_pro_post_classes($classes) {

    // Replace hentry class with entry.
    $classes[] = 'entry';

    return $classes;
}
add_filter('post_class', 'audiocast_pro_post_classes');

/**
 * Remove 'hentry' from post_class()
 */
function audiocast_pro_remove_hentry($class) {
    $class = array_diff($class, array('hentry'));
    return $class;
}
add_filter('post_class', 'audiocast_pro_remove_hentry');

/**
 * Change the excerpt more string.
 */
function audiocast_pro_excerpt_more($more) {
    return '&hellip;';
}
add_filter('excerpt_more', 'audiocast_pro_excerpt_more');

/**
 * Filter the excerpt length.
 */
function audiocast_pro_custom_excerpt_length($length) {

    // Sets default
    $length = 20;

    // Get the user settings
    $setting = get_theme_mod('excerpt', 20);
    if (20 != $setting) {
        $length = $setting;
    }

    if (is_post_type_archive('podcast') || is_page_template('page-templates/home-podcast.php')) {
        $length = 40;
    }

    return $length;
}
add_filter('excerpt_length', 'audiocast_pro_custom_excerpt_length', 999);

/**
 * Extend archive title
 */
function audiocast_pro_extend_archive_title($title) {
    if (is_tax()) {
        $title = single_term_title('', false);
    } elseif (is_home()) {
        $title = esc_html__('Blog', 'audiocast-pro');
    }
    return $title;
}
add_filter('get_the_archive_title', 'audiocast_pro_extend_archive_title');

/**
 * Customize tag cloud widget
 */
function audiocast_pro_customize_tag_cloud($args) {
    $args['largest']  = 13;
    $args['smallest'] = 13;
    $args['unit']     = 'px';
    $args['number']   = 20;
    return $args;
}
add_filter('widget_tag_cloud_args', 'audiocast_pro_customize_tag_cloud');

/**
 * Add a dropdown icon to top-level menu items.
 */
function audiocast_pro_add_dropdown_icons($output, $item, $depth, $args) {

    // Only add class to 'top level' items on the 'primary' menu.
    if ('mobile' !== $args->theme_location) {
        return $output;
    }

    if (in_array('menu-item-has-children', $item->classes, true)) {

        // Add SVG icon to parent items.
        $icon = '<i class="icon-arrow-down"></i>';

        $output .= sprintf(
            '<button class="submenu-expand" tabindex="-1">%s</button>',
            $icon
        );
    }

    return $output;
}
add_filter('walker_nav_menu_start_el', 'audiocast_pro_add_dropdown_icons', 10, 4);

/**
 * Pass one post on Podcast archive page
 */
function audiocast_pro_post_offset($query) {
    if (!is_admin() && $query->is_main_query() && is_post_type_archive('podcast')) {

        $offset = 1;
        $paged = get_option('posts_per_page');

        if ($query->is_paged) {
            $page_offset = $offset + (($query->query_vars['paged'] - 1) * $paged);
            $query->set('offset', $page_offset);
        } else {
            $query->set('offset', $offset);
        }
    }
}
add_action('pre_get_posts', 'audiocast_pro_post_offset', 1);

function audiocast_pro_adjust_offset_pagination($found_posts, $query) {
    $offset = 1;
    if (!is_admin() && $query->is_main_query() && is_post_type_archive('podcast')) {
        return $found_posts - $offset;
    }
    return $found_posts;
}
add_filter('found_posts', 'audiocast_pro_adjust_offset_pagination', 1, 2);
